=========
Changelog
=========

Version 1.23.0
--------------

- b0ef20f Update etos library to version 1.23.0
- 53e313e Add proper exit on activityCanceled event from ETOS (#17)

Version 1.22.0
--------------

- d48fb38 Update etos library to version 1.22.0

Version 1.21.0
--------------

- b7bc1ae Update etos library to version 1.21.0

Version 1.20.0
--------------

- f6d4360 Update etos library to version 1.20.0

Version 1.19.0
--------------

- cb68f7c Update etos library to version 1.19.0

Version 1.18.0
--------------

- a0e9c41 Update etos library to version 1.18.0

Version 1.17.0
--------------

- 8f5693c Update etos library to version 1.17.0

Version 1.16.2
--------------

- 31719f2 Update etos library to version 1.16.2

Version 1.15.0
--------------

- 7cdd5a5 Update etos library to version 1.15.0

Version 1.14.0
--------------

- b3dbc80 Update etos library to version 1.14.0
- d7314c9 Add the ability to provide identity as a UUID (#16)

Version 1.13.0
--------------

- bc3ee47 Update etos library to version 1.13.0

Version 1.12.0
--------------

- d318c93 Update etos library to version 1.12.0

Version 1.11.0
--------------

- 861fddc Update etos library to version 1.11.0

Version 1.10.0
--------------

- c4187a7 Update etos library to version 1.10.0

Version 1.9.0
-------------

- 04c848d Update etos library to version 1.9.0

Version 1.8.0
-------------

- eef3e57 Update etos library to version 1.8.0

Version 1.7.0
-------------

- dfdef2d Update etos library to version 1.7.0

Version 1.6.0
-------------

- dcf48dc Update etos library to version 1.6.0

Version 1.5.0
-------------

- 7e0bcea Update etos library to version 1.5.0
- afefc7a Add a very-verbose input (#14)
- 056b491 Use the event repository from new ETOS API. (#13)

Version 1.4.0
-------------

- 8e7663e Update etos library to version 1.4.0
- ef8afd8 Make sure etos client can download artifacts from events (#12)

Version 1.3.0
-------------

- 64b224e Update etos library to version 1.3.0
- d5a12e1 Fix a problem where test suite failed did not match started (#11)

Version 1.2.0
-------------


Version 1.1.0
-------------

- 8fa2fee Update README.rst (#10)
- 23e625f Add CODEOWNERS file with etos maintainers (#9)
- 006e91d Update README.rst (#8)
